@@ -49,8 +49,8 @@ module Internals
     1257 => "WINDOWS-1257", #(Baltic)
     1258 => "WINDOWS-1258", #(Vietnamese)
     1361 => "WINDOWS-1361", #(Korean (Johab))
-    10000 => "MACINTOSH",
-    32768 => "MACINTOSH",
+    10000 => "MACROMAN",
+    32768 => "MACROMAN",
     32769 => "WINDOWS-1252", #(Latin I) (BIFF2-BIFF3)
   }
   SEGAPEDOC = CODEPAGES.invert
@@ -162,6 +162,7 @@ module Internals
     :labelsst   => 'v3V',
     :number     => "v3#{EIGHT_BYTE_DOUBLE}",
     :pagesetup  => "v8#{EIGHT_BYTE_DOUBLE}2v",
+    :margin     => "#{EIGHT_BYTE_DOUBLE}",
     :rk         => 'v3V',
     :row        => 'v4x4V',
     :window2    => 'v4x2v2x4',
