@@ -193,7 +193,7 @@ class Workbook < Spreadsheet::Writer
         reader.seek lastpos = 0
         workbook.offsets.select do |key, pair|
           workbook.changes.include? key
-        end.sort_by do |key, (pos, len)|
+        end.sort_by do |key, (pos, _)|
           pos
         end.each do |key, (pos, len)|
           data = reader.read(pos - lastpos)
@@ -434,6 +434,7 @@ class Workbook < Spreadsheet::Writer
     # ●● STYLE ➜ 5.103
     write_styles workbook, buffer1
     # ○  PALETTE ➜ 5.74
+    write_palette workbook, buffer1
     # ○  USESELFS ➜ 5.106
     buffer1.rewind
     # ●● BOUNDSHEET ➜ 5.95
@@ -538,7 +539,7 @@ class Workbook < Spreadsheet::Writer
     ## if we're writing wide characters, we need to make sure we don't cut
     #  characters in half
     if wide > 0 && data.size > @recordsize_limit
-      remove = @recordsize_limit - data.size
+      remove = @recordsize_limit - bef
       remove -= remove % 2
       rest = data.slice!(remove..-1)
       write_op writer, op, data
@@ -588,6 +589,18 @@ class Workbook < Spreadsheet::Writer
     ]
     write_op writer, 0x0293, data.pack('vC2')
   end
+  def write_palette workbook, writer
+    data = default_palette
+
+    workbook.palette.each do |idx, color|
+      idx = SEDOC_ROLOC[idx] - 8 if idx.kind_of? Symbol
+      raise "Undefined color index: #{idx}" unless data[idx]
+      data[idx] = color
+    end
+
+    writer.write [opcode(:palette), 2 + 4 * data.size, data.size].pack('v3')
+    writer.write data.collect { |c| c.push(0).pack('C4') }.join
+  end
   def write_tabid workbook, writer
     write_op writer, 0x013d, [1].pack('v')
   end
@@ -653,6 +666,68 @@ class Workbook < Spreadsheet::Writer
   def xf_index workbook, format
     @formats[workbook][:xf_indexes][format] || 0
   end
+  ##
+  # Returns Excel 97+ default colour palette.
+  def default_palette
+    [
+      [0x00, 0x00, 0x00],
+      [0xff, 0xff, 0xff],
+      [0xff, 0x00, 0x00],
+      [0x00, 0xff, 0x00],
+      [0x00, 0x00, 0xff],
+      [0xff, 0xff, 0x00],
+      [0xff, 0x00, 0xff],
+      [0x00, 0xff, 0xff],
+      [0x80, 0x00, 0x00],
+      [0x00, 0x80, 0x00],
+      [0x00, 0x00, 0x80],
+      [0x80, 0x80, 0x00],
+      [0x80, 0x00, 0x80],
+      [0x00, 0x80, 0x80],
+      [0xc0, 0xc0, 0xc0],
+      [0x80, 0x80, 0x80],
+      [0x99, 0x99, 0xff],
+      [0x99, 0x33, 0x66],
+      [0xff, 0xff, 0xcc],
+      [0xcc, 0xff, 0xff],
+      [0x66, 0x00, 0x66],
+      [0xff, 0x80, 0x80],
+      [0x00, 0x66, 0xcc],
+      [0xcc, 0xcc, 0xff],
+      [0x00, 0x00, 0x80],
+      [0xff, 0x00, 0xff],
+      [0xff, 0xff, 0x00],
+      [0x00, 0xff, 0xff],
+      [0x80, 0x00, 0x80],
+      [0x80, 0x00, 0x00],
+      [0x00, 0x80, 0x80],
+      [0x00, 0x00, 0xff],
+      [0x00, 0xcc, 0xff],
+      [0xcc, 0xff, 0xff],
+      [0xcc, 0xff, 0xcc],
+      [0xff, 0xff, 0x99],
+      [0x99, 0xcc, 0xff],
+      [0xff, 0x99, 0xcc],
+      [0xcc, 0x99, 0xff],
+      [0xff, 0xcc, 0x99],
+      [0x33, 0x66, 0xff],
+      [0x33, 0xcc, 0xcc],
+      [0x99, 0xcc, 0x00],
+      [0xff, 0xcc, 0x00],
+      [0xff, 0x99, 0x00],
+      [0xff, 0x66, 0x00],
+      [0x66, 0x66, 0x99],
+      [0x96, 0x96, 0x96],
+      [0x00, 0x33, 0x66],
+      [0x33, 0x99, 0x66],
+      [0x00, 0x33, 0x00],
+      [0x33, 0x33, 0x00],
+      [0x99, 0x33, 0x00],
+      [0x99, 0x33, 0x66],
+      [0x33, 0x33, 0x99],
+      [0x33, 0x33, 0x33]
+    ]
+  end
 end
     end
   end
